@@ -5,10 +5,12 @@ if __name__ == '__main__':
     # Create a user to test with
     app_dir = os.path.realpath(os.path.dirname(__file__))
     database_path = os.path.join(app_dir, app.import_name, app.config['DATABASE_FILE'])
-    if not os.path.exists(database_path):
-        with app.app_context():
-            db.create_all()
-            
+    
+    with app.app_context():
+        db.create_all()
+        db.session.commit()
+        
+        if Role.quey.get(1).name != "admin":
             # add default role
             user_role = Role(name='user')
             admin_role = Role(name='admin')
